# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'BackupInstanceKubernetesClusterBackupDatasourceParameters',
    'BackupPolicyBlobStorageRetentionRule',
    'BackupPolicyBlobStorageRetentionRuleCriteria',
    'BackupPolicyBlobStorageRetentionRuleLifeCycle',
    'BackupPolicyDiskRetentionRule',
    'BackupPolicyDiskRetentionRuleCriteria',
    'BackupPolicyKubernetesClusterDefaultRetentionRule',
    'BackupPolicyKubernetesClusterDefaultRetentionRuleLifeCycle',
    'BackupPolicyKubernetesClusterRetentionRule',
    'BackupPolicyKubernetesClusterRetentionRuleCriteria',
    'BackupPolicyKubernetesClusterRetentionRuleLifeCycle',
    'BackupPolicyMysqlFlexibleServerDefaultRetentionRule',
    'BackupPolicyMysqlFlexibleServerDefaultRetentionRuleLifeCycle',
    'BackupPolicyMysqlFlexibleServerRetentionRule',
    'BackupPolicyMysqlFlexibleServerRetentionRuleCriteria',
    'BackupPolicyMysqlFlexibleServerRetentionRuleLifeCycle',
    'BackupPolicyPostgresqlFlexibleServerDefaultRetentionRule',
    'BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleLifeCycle',
    'BackupPolicyPostgresqlFlexibleServerRetentionRule',
    'BackupPolicyPostgresqlFlexibleServerRetentionRuleCriteria',
    'BackupPolicyPostgresqlFlexibleServerRetentionRuleLifeCycle',
    'BackupPolicyPostgresqlRetentionRule',
    'BackupPolicyPostgresqlRetentionRuleCriteria',
    'BackupVaultIdentity',
    'GetBackupVaultIdentityResult',
]

@pulumi.output_type
class BackupInstanceKubernetesClusterBackupDatasourceParameters(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "clusterScopedResourcesEnabled":
            suggest = "cluster_scoped_resources_enabled"
        elif key == "excludedNamespaces":
            suggest = "excluded_namespaces"
        elif key == "excludedResourceTypes":
            suggest = "excluded_resource_types"
        elif key == "includedNamespaces":
            suggest = "included_namespaces"
        elif key == "includedResourceTypes":
            suggest = "included_resource_types"
        elif key == "labelSelectors":
            suggest = "label_selectors"
        elif key == "volumeSnapshotEnabled":
            suggest = "volume_snapshot_enabled"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupInstanceKubernetesClusterBackupDatasourceParameters. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupInstanceKubernetesClusterBackupDatasourceParameters.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupInstanceKubernetesClusterBackupDatasourceParameters.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cluster_scoped_resources_enabled: Optional[bool] = None,
                 excluded_namespaces: Optional[Sequence[str]] = None,
                 excluded_resource_types: Optional[Sequence[str]] = None,
                 included_namespaces: Optional[Sequence[str]] = None,
                 included_resource_types: Optional[Sequence[str]] = None,
                 label_selectors: Optional[Sequence[str]] = None,
                 volume_snapshot_enabled: Optional[bool] = None):
        """
        :param bool cluster_scoped_resources_enabled: Whether to include cluster scope resources during backup. Default to `false`. Changing this forces a new resource to be created.
        :param Sequence[str] excluded_namespaces: Specifies the namespaces to be excluded during backup. Changing this forces a new resource to be created.
        :param Sequence[str] excluded_resource_types: Specifies the resource types to be excluded during backup. Changing this forces a new resource to be created.
        :param Sequence[str] included_namespaces: Specifies the namespaces to be included during backup. Changing this forces a new resource to be created.
        :param Sequence[str] included_resource_types: Specifies the resource types to be included during backup. Changing this forces a new resource to be created.
        :param Sequence[str] label_selectors: Specifies the resources with such label selectors to be included during backup. Changing this forces a new resource to be created.
        :param bool volume_snapshot_enabled: Whether to take volume snapshots during backup. Default to `false`. Changing this forces a new resource to be created.
        """
        if cluster_scoped_resources_enabled is not None:
            pulumi.set(__self__, "cluster_scoped_resources_enabled", cluster_scoped_resources_enabled)
        if excluded_namespaces is not None:
            pulumi.set(__self__, "excluded_namespaces", excluded_namespaces)
        if excluded_resource_types is not None:
            pulumi.set(__self__, "excluded_resource_types", excluded_resource_types)
        if included_namespaces is not None:
            pulumi.set(__self__, "included_namespaces", included_namespaces)
        if included_resource_types is not None:
            pulumi.set(__self__, "included_resource_types", included_resource_types)
        if label_selectors is not None:
            pulumi.set(__self__, "label_selectors", label_selectors)
        if volume_snapshot_enabled is not None:
            pulumi.set(__self__, "volume_snapshot_enabled", volume_snapshot_enabled)

    @property
    @pulumi.getter(name="clusterScopedResourcesEnabled")
    def cluster_scoped_resources_enabled(self) -> Optional[bool]:
        """
        Whether to include cluster scope resources during backup. Default to `false`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cluster_scoped_resources_enabled")

    @property
    @pulumi.getter(name="excludedNamespaces")
    def excluded_namespaces(self) -> Optional[Sequence[str]]:
        """
        Specifies the namespaces to be excluded during backup. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "excluded_namespaces")

    @property
    @pulumi.getter(name="excludedResourceTypes")
    def excluded_resource_types(self) -> Optional[Sequence[str]]:
        """
        Specifies the resource types to be excluded during backup. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "excluded_resource_types")

    @property
    @pulumi.getter(name="includedNamespaces")
    def included_namespaces(self) -> Optional[Sequence[str]]:
        """
        Specifies the namespaces to be included during backup. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "included_namespaces")

    @property
    @pulumi.getter(name="includedResourceTypes")
    def included_resource_types(self) -> Optional[Sequence[str]]:
        """
        Specifies the resource types to be included during backup. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "included_resource_types")

    @property
    @pulumi.getter(name="labelSelectors")
    def label_selectors(self) -> Optional[Sequence[str]]:
        """
        Specifies the resources with such label selectors to be included during backup. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "label_selectors")

    @property
    @pulumi.getter(name="volumeSnapshotEnabled")
    def volume_snapshot_enabled(self) -> Optional[bool]:
        """
        Whether to take volume snapshots during backup. Default to `false`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "volume_snapshot_enabled")


@pulumi.output_type
class BackupPolicyBlobStorageRetentionRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lifeCycle":
            suggest = "life_cycle"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyBlobStorageRetentionRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyBlobStorageRetentionRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyBlobStorageRetentionRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 criteria: 'outputs.BackupPolicyBlobStorageRetentionRuleCriteria',
                 life_cycle: 'outputs.BackupPolicyBlobStorageRetentionRuleLifeCycle',
                 name: str,
                 priority: int):
        """
        :param 'BackupPolicyBlobStorageRetentionRuleCriteriaArgs' criteria: A `criteria` block as defined below. Changing this forces a new Backup Policy Blob Storage to be created.
        :param 'BackupPolicyBlobStorageRetentionRuleLifeCycleArgs' life_cycle: A `life_cycle` block as defined below. Changing this forces a new Backup Policy Blob Storage to be created.
        :param str name: The name which should be used for this retention rule. Changing this forces a new Backup Policy Blob Storage to be created.
        :param int priority: Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        pulumi.set(__self__, "criteria", criteria)
        pulumi.set(__self__, "life_cycle", life_cycle)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "priority", priority)

    @property
    @pulumi.getter
    def criteria(self) -> 'outputs.BackupPolicyBlobStorageRetentionRuleCriteria':
        """
        A `criteria` block as defined below. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "criteria")

    @property
    @pulumi.getter(name="lifeCycle")
    def life_cycle(self) -> 'outputs.BackupPolicyBlobStorageRetentionRuleLifeCycle':
        """
        A `life_cycle` block as defined below. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "life_cycle")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name which should be used for this retention rule. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def priority(self) -> int:
        """
        Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "priority")


@pulumi.output_type
class BackupPolicyBlobStorageRetentionRuleCriteria(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "absoluteCriteria":
            suggest = "absolute_criteria"
        elif key == "daysOfMonths":
            suggest = "days_of_months"
        elif key == "daysOfWeeks":
            suggest = "days_of_weeks"
        elif key == "monthsOfYears":
            suggest = "months_of_years"
        elif key == "scheduledBackupTimes":
            suggest = "scheduled_backup_times"
        elif key == "weeksOfMonths":
            suggest = "weeks_of_months"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyBlobStorageRetentionRuleCriteria. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyBlobStorageRetentionRuleCriteria.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyBlobStorageRetentionRuleCriteria.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 absolute_criteria: Optional[str] = None,
                 days_of_months: Optional[Sequence[int]] = None,
                 days_of_weeks: Optional[Sequence[str]] = None,
                 months_of_years: Optional[Sequence[str]] = None,
                 scheduled_backup_times: Optional[Sequence[str]] = None,
                 weeks_of_months: Optional[Sequence[str]] = None):
        """
        :param str absolute_criteria: Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new Backup Policy Blob Storage to be created.
        :param Sequence[int] days_of_months: Must be between `0` and `28`. `0` for last day within the month. Changing this forces a new Backup Policy Blob Storage to be created.
        :param Sequence[str] days_of_weeks: Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new Backup Policy Blob Storage to be created.
        :param Sequence[str] months_of_years: Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new Backup Policy Blob Storage to be created.
        :param Sequence[str] scheduled_backup_times: Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new Backup Policy Blob Storage to be created.
        :param Sequence[str] weeks_of_months: Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        if absolute_criteria is not None:
            pulumi.set(__self__, "absolute_criteria", absolute_criteria)
        if days_of_months is not None:
            pulumi.set(__self__, "days_of_months", days_of_months)
        if days_of_weeks is not None:
            pulumi.set(__self__, "days_of_weeks", days_of_weeks)
        if months_of_years is not None:
            pulumi.set(__self__, "months_of_years", months_of_years)
        if scheduled_backup_times is not None:
            pulumi.set(__self__, "scheduled_backup_times", scheduled_backup_times)
        if weeks_of_months is not None:
            pulumi.set(__self__, "weeks_of_months", weeks_of_months)

    @property
    @pulumi.getter(name="absoluteCriteria")
    def absolute_criteria(self) -> Optional[str]:
        """
        Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "absolute_criteria")

    @property
    @pulumi.getter(name="daysOfMonths")
    def days_of_months(self) -> Optional[Sequence[int]]:
        """
        Must be between `0` and `28`. `0` for last day within the month. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "days_of_months")

    @property
    @pulumi.getter(name="daysOfWeeks")
    def days_of_weeks(self) -> Optional[Sequence[str]]:
        """
        Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "days_of_weeks")

    @property
    @pulumi.getter(name="monthsOfYears")
    def months_of_years(self) -> Optional[Sequence[str]]:
        """
        Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "months_of_years")

    @property
    @pulumi.getter(name="scheduledBackupTimes")
    def scheduled_backup_times(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "scheduled_backup_times")

    @property
    @pulumi.getter(name="weeksOfMonths")
    def weeks_of_months(self) -> Optional[Sequence[str]]:
        """
        Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "weeks_of_months")


@pulumi.output_type
class BackupPolicyBlobStorageRetentionRuleLifeCycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataStoreType":
            suggest = "data_store_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyBlobStorageRetentionRuleLifeCycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyBlobStorageRetentionRuleLifeCycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyBlobStorageRetentionRuleLifeCycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_store_type: str,
                 duration: str):
        """
        :param str data_store_type: The type of data store. The only possible value is `VaultStore`. Changing this forces a new Backup Policy Blob Storage to be created.
        :param str duration: The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        pulumi.set(__self__, "data_store_type", data_store_type)
        pulumi.set(__self__, "duration", duration)

    @property
    @pulumi.getter(name="dataStoreType")
    def data_store_type(self) -> str:
        """
        The type of data store. The only possible value is `VaultStore`. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "data_store_type")

    @property
    @pulumi.getter
    def duration(self) -> str:
        """
        The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new Backup Policy Blob Storage to be created.
        """
        return pulumi.get(self, "duration")


@pulumi.output_type
class BackupPolicyDiskRetentionRule(dict):
    def __init__(__self__, *,
                 criteria: 'outputs.BackupPolicyDiskRetentionRuleCriteria',
                 duration: str,
                 name: str,
                 priority: int):
        """
        :param 'BackupPolicyDiskRetentionRuleCriteriaArgs' criteria: A `criteria` block as defined below. Changing this forces a new Backup Policy Disk to be created.
        :param str duration: Duration of deletion after given timespan. It should follow `ISO 8601` duration format. Changing this forces a new Backup Policy Disk to be created.
        :param str name: The name which should be used for this retention rule. Changing this forces a new Backup Policy Disk to be created.
        :param int priority: Retention Tag priority. Changing this forces a new Backup Policy Disk to be created.
        """
        pulumi.set(__self__, "criteria", criteria)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "priority", priority)

    @property
    @pulumi.getter
    def criteria(self) -> 'outputs.BackupPolicyDiskRetentionRuleCriteria':
        """
        A `criteria` block as defined below. Changing this forces a new Backup Policy Disk to be created.
        """
        return pulumi.get(self, "criteria")

    @property
    @pulumi.getter
    def duration(self) -> str:
        """
        Duration of deletion after given timespan. It should follow `ISO 8601` duration format. Changing this forces a new Backup Policy Disk to be created.
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name which should be used for this retention rule. Changing this forces a new Backup Policy Disk to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def priority(self) -> int:
        """
        Retention Tag priority. Changing this forces a new Backup Policy Disk to be created.
        """
        return pulumi.get(self, "priority")


@pulumi.output_type
class BackupPolicyDiskRetentionRuleCriteria(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "absoluteCriteria":
            suggest = "absolute_criteria"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyDiskRetentionRuleCriteria. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyDiskRetentionRuleCriteria.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyDiskRetentionRuleCriteria.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 absolute_criteria: Optional[str] = None):
        """
        :param str absolute_criteria: Possible values are `FirstOfDay` and `FirstOfWeek`. Changing this forces a new Backup Policy Disk to be created.
        """
        if absolute_criteria is not None:
            pulumi.set(__self__, "absolute_criteria", absolute_criteria)

    @property
    @pulumi.getter(name="absoluteCriteria")
    def absolute_criteria(self) -> Optional[str]:
        """
        Possible values are `FirstOfDay` and `FirstOfWeek`. Changing this forces a new Backup Policy Disk to be created.
        """
        return pulumi.get(self, "absolute_criteria")


@pulumi.output_type
class BackupPolicyKubernetesClusterDefaultRetentionRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lifeCycles":
            suggest = "life_cycles"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyKubernetesClusterDefaultRetentionRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyKubernetesClusterDefaultRetentionRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyKubernetesClusterDefaultRetentionRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 life_cycles: Sequence['outputs.BackupPolicyKubernetesClusterDefaultRetentionRuleLifeCycle']):
        """
        :param Sequence['BackupPolicyKubernetesClusterDefaultRetentionRuleLifeCycleArgs'] life_cycles: A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "life_cycles", life_cycles)

    @property
    @pulumi.getter(name="lifeCycles")
    def life_cycles(self) -> Sequence['outputs.BackupPolicyKubernetesClusterDefaultRetentionRuleLifeCycle']:
        """
        A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "life_cycles")


@pulumi.output_type
class BackupPolicyKubernetesClusterDefaultRetentionRuleLifeCycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataStoreType":
            suggest = "data_store_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyKubernetesClusterDefaultRetentionRuleLifeCycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyKubernetesClusterDefaultRetentionRuleLifeCycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyKubernetesClusterDefaultRetentionRuleLifeCycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_store_type: str,
                 duration: str):
        """
        :param str data_store_type: The type of data store. The only possible value is `OperationalStore`. Changing this forces a new resource to be created.
        :param str duration: The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "data_store_type", data_store_type)
        pulumi.set(__self__, "duration", duration)

    @property
    @pulumi.getter(name="dataStoreType")
    def data_store_type(self) -> str:
        """
        The type of data store. The only possible value is `OperationalStore`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "data_store_type")

    @property
    @pulumi.getter
    def duration(self) -> str:
        """
        The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration")


@pulumi.output_type
class BackupPolicyKubernetesClusterRetentionRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lifeCycles":
            suggest = "life_cycles"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyKubernetesClusterRetentionRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyKubernetesClusterRetentionRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyKubernetesClusterRetentionRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 criteria: 'outputs.BackupPolicyKubernetesClusterRetentionRuleCriteria',
                 life_cycles: Sequence['outputs.BackupPolicyKubernetesClusterRetentionRuleLifeCycle'],
                 name: str,
                 priority: int):
        """
        :param 'BackupPolicyKubernetesClusterRetentionRuleCriteriaArgs' criteria: A `criteria` block as defined below. Changing this forces a new resource to be created.
        :param Sequence['BackupPolicyKubernetesClusterRetentionRuleLifeCycleArgs'] life_cycles: A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        :param str name: The name which should be used for this retention rule. Changing this forces a new resource to be created.
        :param int priority: Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "criteria", criteria)
        pulumi.set(__self__, "life_cycles", life_cycles)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "priority", priority)

    @property
    @pulumi.getter
    def criteria(self) -> 'outputs.BackupPolicyKubernetesClusterRetentionRuleCriteria':
        """
        A `criteria` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "criteria")

    @property
    @pulumi.getter(name="lifeCycles")
    def life_cycles(self) -> Sequence['outputs.BackupPolicyKubernetesClusterRetentionRuleLifeCycle']:
        """
        A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "life_cycles")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name which should be used for this retention rule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def priority(self) -> int:
        """
        Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "priority")


@pulumi.output_type
class BackupPolicyKubernetesClusterRetentionRuleCriteria(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "absoluteCriteria":
            suggest = "absolute_criteria"
        elif key == "daysOfWeeks":
            suggest = "days_of_weeks"
        elif key == "monthsOfYears":
            suggest = "months_of_years"
        elif key == "scheduledBackupTimes":
            suggest = "scheduled_backup_times"
        elif key == "weeksOfMonths":
            suggest = "weeks_of_months"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyKubernetesClusterRetentionRuleCriteria. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyKubernetesClusterRetentionRuleCriteria.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyKubernetesClusterRetentionRuleCriteria.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 absolute_criteria: Optional[str] = None,
                 days_of_weeks: Optional[Sequence[str]] = None,
                 months_of_years: Optional[Sequence[str]] = None,
                 scheduled_backup_times: Optional[Sequence[str]] = None,
                 weeks_of_months: Optional[Sequence[str]] = None):
        """
        :param str absolute_criteria: Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new resource to be created.
        :param Sequence[str] days_of_weeks: Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new resource to be created.
        :param Sequence[str] months_of_years: Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new resource to be created.
        :param Sequence[str] scheduled_backup_times: Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new resource to be created.
        :param Sequence[str] weeks_of_months: Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new resource to be created.
        """
        if absolute_criteria is not None:
            pulumi.set(__self__, "absolute_criteria", absolute_criteria)
        if days_of_weeks is not None:
            pulumi.set(__self__, "days_of_weeks", days_of_weeks)
        if months_of_years is not None:
            pulumi.set(__self__, "months_of_years", months_of_years)
        if scheduled_backup_times is not None:
            pulumi.set(__self__, "scheduled_backup_times", scheduled_backup_times)
        if weeks_of_months is not None:
            pulumi.set(__self__, "weeks_of_months", weeks_of_months)

    @property
    @pulumi.getter(name="absoluteCriteria")
    def absolute_criteria(self) -> Optional[str]:
        """
        Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "absolute_criteria")

    @property
    @pulumi.getter(name="daysOfWeeks")
    def days_of_weeks(self) -> Optional[Sequence[str]]:
        """
        Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "days_of_weeks")

    @property
    @pulumi.getter(name="monthsOfYears")
    def months_of_years(self) -> Optional[Sequence[str]]:
        """
        Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "months_of_years")

    @property
    @pulumi.getter(name="scheduledBackupTimes")
    def scheduled_backup_times(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "scheduled_backup_times")

    @property
    @pulumi.getter(name="weeksOfMonths")
    def weeks_of_months(self) -> Optional[Sequence[str]]:
        """
        Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "weeks_of_months")


@pulumi.output_type
class BackupPolicyKubernetesClusterRetentionRuleLifeCycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataStoreType":
            suggest = "data_store_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyKubernetesClusterRetentionRuleLifeCycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyKubernetesClusterRetentionRuleLifeCycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyKubernetesClusterRetentionRuleLifeCycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_store_type: str,
                 duration: str):
        """
        :param str data_store_type: The type of data store. The only possible value is `OperationalStore`. Changing this forces a new resource to be created.
        :param str duration: The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "data_store_type", data_store_type)
        pulumi.set(__self__, "duration", duration)

    @property
    @pulumi.getter(name="dataStoreType")
    def data_store_type(self) -> str:
        """
        The type of data store. The only possible value is `OperationalStore`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "data_store_type")

    @property
    @pulumi.getter
    def duration(self) -> str:
        """
        The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration")


@pulumi.output_type
class BackupPolicyMysqlFlexibleServerDefaultRetentionRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lifeCycles":
            suggest = "life_cycles"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyMysqlFlexibleServerDefaultRetentionRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyMysqlFlexibleServerDefaultRetentionRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyMysqlFlexibleServerDefaultRetentionRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 life_cycles: Sequence['outputs.BackupPolicyMysqlFlexibleServerDefaultRetentionRuleLifeCycle']):
        """
        :param Sequence['BackupPolicyMysqlFlexibleServerDefaultRetentionRuleLifeCycleArgs'] life_cycles: A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "life_cycles", life_cycles)

    @property
    @pulumi.getter(name="lifeCycles")
    def life_cycles(self) -> Sequence['outputs.BackupPolicyMysqlFlexibleServerDefaultRetentionRuleLifeCycle']:
        """
        A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "life_cycles")


@pulumi.output_type
class BackupPolicyMysqlFlexibleServerDefaultRetentionRuleLifeCycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataStoreType":
            suggest = "data_store_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyMysqlFlexibleServerDefaultRetentionRuleLifeCycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyMysqlFlexibleServerDefaultRetentionRuleLifeCycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyMysqlFlexibleServerDefaultRetentionRuleLifeCycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_store_type: str,
                 duration: str):
        """
        :param str data_store_type: The type of data store. The only possible value is `VaultStore`. Changing this forces a new resource to be created.
        :param str duration: The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "data_store_type", data_store_type)
        pulumi.set(__self__, "duration", duration)

    @property
    @pulumi.getter(name="dataStoreType")
    def data_store_type(self) -> str:
        """
        The type of data store. The only possible value is `VaultStore`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "data_store_type")

    @property
    @pulumi.getter
    def duration(self) -> str:
        """
        The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration")


@pulumi.output_type
class BackupPolicyMysqlFlexibleServerRetentionRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lifeCycles":
            suggest = "life_cycles"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyMysqlFlexibleServerRetentionRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyMysqlFlexibleServerRetentionRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyMysqlFlexibleServerRetentionRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 criteria: 'outputs.BackupPolicyMysqlFlexibleServerRetentionRuleCriteria',
                 life_cycles: Sequence['outputs.BackupPolicyMysqlFlexibleServerRetentionRuleLifeCycle'],
                 name: str,
                 priority: int):
        """
        :param 'BackupPolicyMysqlFlexibleServerRetentionRuleCriteriaArgs' criteria: A `criteria` block as defined below. Changing this forces a new resource to be created.
        :param Sequence['BackupPolicyMysqlFlexibleServerRetentionRuleLifeCycleArgs'] life_cycles: A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        :param str name: Specifies the name of the retention rule. Changing this forces a new resource to be created.
        :param int priority: Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "criteria", criteria)
        pulumi.set(__self__, "life_cycles", life_cycles)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "priority", priority)

    @property
    @pulumi.getter
    def criteria(self) -> 'outputs.BackupPolicyMysqlFlexibleServerRetentionRuleCriteria':
        """
        A `criteria` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "criteria")

    @property
    @pulumi.getter(name="lifeCycles")
    def life_cycles(self) -> Sequence['outputs.BackupPolicyMysqlFlexibleServerRetentionRuleLifeCycle']:
        """
        A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "life_cycles")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Specifies the name of the retention rule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def priority(self) -> int:
        """
        Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "priority")


@pulumi.output_type
class BackupPolicyMysqlFlexibleServerRetentionRuleCriteria(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "absoluteCriteria":
            suggest = "absolute_criteria"
        elif key == "daysOfWeeks":
            suggest = "days_of_weeks"
        elif key == "monthsOfYears":
            suggest = "months_of_years"
        elif key == "scheduledBackupTimes":
            suggest = "scheduled_backup_times"
        elif key == "weeksOfMonths":
            suggest = "weeks_of_months"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyMysqlFlexibleServerRetentionRuleCriteria. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyMysqlFlexibleServerRetentionRuleCriteria.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyMysqlFlexibleServerRetentionRuleCriteria.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 absolute_criteria: Optional[str] = None,
                 days_of_weeks: Optional[Sequence[str]] = None,
                 months_of_years: Optional[Sequence[str]] = None,
                 scheduled_backup_times: Optional[Sequence[str]] = None,
                 weeks_of_months: Optional[Sequence[str]] = None):
        """
        :param str absolute_criteria: Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new resource to be created.
        :param Sequence[str] days_of_weeks: Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new resource to be created.
        :param Sequence[str] months_of_years: Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new resource to be created.
        :param Sequence[str] scheduled_backup_times: Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new resource to be created.
        :param Sequence[str] weeks_of_months: Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new resource to be created.
        """
        if absolute_criteria is not None:
            pulumi.set(__self__, "absolute_criteria", absolute_criteria)
        if days_of_weeks is not None:
            pulumi.set(__self__, "days_of_weeks", days_of_weeks)
        if months_of_years is not None:
            pulumi.set(__self__, "months_of_years", months_of_years)
        if scheduled_backup_times is not None:
            pulumi.set(__self__, "scheduled_backup_times", scheduled_backup_times)
        if weeks_of_months is not None:
            pulumi.set(__self__, "weeks_of_months", weeks_of_months)

    @property
    @pulumi.getter(name="absoluteCriteria")
    def absolute_criteria(self) -> Optional[str]:
        """
        Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "absolute_criteria")

    @property
    @pulumi.getter(name="daysOfWeeks")
    def days_of_weeks(self) -> Optional[Sequence[str]]:
        """
        Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "days_of_weeks")

    @property
    @pulumi.getter(name="monthsOfYears")
    def months_of_years(self) -> Optional[Sequence[str]]:
        """
        Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "months_of_years")

    @property
    @pulumi.getter(name="scheduledBackupTimes")
    def scheduled_backup_times(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "scheduled_backup_times")

    @property
    @pulumi.getter(name="weeksOfMonths")
    def weeks_of_months(self) -> Optional[Sequence[str]]:
        """
        Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "weeks_of_months")


@pulumi.output_type
class BackupPolicyMysqlFlexibleServerRetentionRuleLifeCycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataStoreType":
            suggest = "data_store_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyMysqlFlexibleServerRetentionRuleLifeCycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyMysqlFlexibleServerRetentionRuleLifeCycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyMysqlFlexibleServerRetentionRuleLifeCycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_store_type: str,
                 duration: str):
        """
        :param str data_store_type: The type of data store. The only possible value is `VaultStore`. Changing this forces a new resource to be created.
        :param str duration: The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "data_store_type", data_store_type)
        pulumi.set(__self__, "duration", duration)

    @property
    @pulumi.getter(name="dataStoreType")
    def data_store_type(self) -> str:
        """
        The type of data store. The only possible value is `VaultStore`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "data_store_type")

    @property
    @pulumi.getter
    def duration(self) -> str:
        """
        The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration")


@pulumi.output_type
class BackupPolicyPostgresqlFlexibleServerDefaultRetentionRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lifeCycles":
            suggest = "life_cycles"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyPostgresqlFlexibleServerDefaultRetentionRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyPostgresqlFlexibleServerDefaultRetentionRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyPostgresqlFlexibleServerDefaultRetentionRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 life_cycles: Sequence['outputs.BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleLifeCycle']):
        """
        :param Sequence['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleLifeCycleArgs'] life_cycles: A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "life_cycles", life_cycles)

    @property
    @pulumi.getter(name="lifeCycles")
    def life_cycles(self) -> Sequence['outputs.BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleLifeCycle']:
        """
        A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "life_cycles")


@pulumi.output_type
class BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleLifeCycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataStoreType":
            suggest = "data_store_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleLifeCycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleLifeCycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleLifeCycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_store_type: str,
                 duration: str):
        """
        :param str data_store_type: The type of data store. The only possible value is `VaultStore`. Changing this forces a new resource to be created.
        :param str duration: The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "data_store_type", data_store_type)
        pulumi.set(__self__, "duration", duration)

    @property
    @pulumi.getter(name="dataStoreType")
    def data_store_type(self) -> str:
        """
        The type of data store. The only possible value is `VaultStore`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "data_store_type")

    @property
    @pulumi.getter
    def duration(self) -> str:
        """
        The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration")


@pulumi.output_type
class BackupPolicyPostgresqlFlexibleServerRetentionRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lifeCycles":
            suggest = "life_cycles"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyPostgresqlFlexibleServerRetentionRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyPostgresqlFlexibleServerRetentionRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyPostgresqlFlexibleServerRetentionRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 criteria: 'outputs.BackupPolicyPostgresqlFlexibleServerRetentionRuleCriteria',
                 life_cycles: Sequence['outputs.BackupPolicyPostgresqlFlexibleServerRetentionRuleLifeCycle'],
                 name: str,
                 priority: int):
        """
        :param 'BackupPolicyPostgresqlFlexibleServerRetentionRuleCriteriaArgs' criteria: A `criteria` block as defined below. Changing this forces a new resource to be created.
        :param Sequence['BackupPolicyPostgresqlFlexibleServerRetentionRuleLifeCycleArgs'] life_cycles: A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        :param str name: Specifies the name of the retention rule. Changing this forces a new resource to be created.
        :param int priority: Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "criteria", criteria)
        pulumi.set(__self__, "life_cycles", life_cycles)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "priority", priority)

    @property
    @pulumi.getter
    def criteria(self) -> 'outputs.BackupPolicyPostgresqlFlexibleServerRetentionRuleCriteria':
        """
        A `criteria` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "criteria")

    @property
    @pulumi.getter(name="lifeCycles")
    def life_cycles(self) -> Sequence['outputs.BackupPolicyPostgresqlFlexibleServerRetentionRuleLifeCycle']:
        """
        A `life_cycle` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "life_cycles")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Specifies the name of the retention rule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def priority(self) -> int:
        """
        Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "priority")


@pulumi.output_type
class BackupPolicyPostgresqlFlexibleServerRetentionRuleCriteria(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "absoluteCriteria":
            suggest = "absolute_criteria"
        elif key == "daysOfWeeks":
            suggest = "days_of_weeks"
        elif key == "monthsOfYears":
            suggest = "months_of_years"
        elif key == "scheduledBackupTimes":
            suggest = "scheduled_backup_times"
        elif key == "weeksOfMonths":
            suggest = "weeks_of_months"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyPostgresqlFlexibleServerRetentionRuleCriteria. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyPostgresqlFlexibleServerRetentionRuleCriteria.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyPostgresqlFlexibleServerRetentionRuleCriteria.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 absolute_criteria: Optional[str] = None,
                 days_of_weeks: Optional[Sequence[str]] = None,
                 months_of_years: Optional[Sequence[str]] = None,
                 scheduled_backup_times: Optional[Sequence[str]] = None,
                 weeks_of_months: Optional[Sequence[str]] = None):
        """
        :param str absolute_criteria: Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new resource to be created.
        :param Sequence[str] days_of_weeks: Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new resource to be created.
        :param Sequence[str] months_of_years: Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new resource to be created.
        :param Sequence[str] scheduled_backup_times: Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new resource to be created.
        :param Sequence[str] weeks_of_months: Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new resource to be created.
        """
        if absolute_criteria is not None:
            pulumi.set(__self__, "absolute_criteria", absolute_criteria)
        if days_of_weeks is not None:
            pulumi.set(__self__, "days_of_weeks", days_of_weeks)
        if months_of_years is not None:
            pulumi.set(__self__, "months_of_years", months_of_years)
        if scheduled_backup_times is not None:
            pulumi.set(__self__, "scheduled_backup_times", scheduled_backup_times)
        if weeks_of_months is not None:
            pulumi.set(__self__, "weeks_of_months", weeks_of_months)

    @property
    @pulumi.getter(name="absoluteCriteria")
    def absolute_criteria(self) -> Optional[str]:
        """
        Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "absolute_criteria")

    @property
    @pulumi.getter(name="daysOfWeeks")
    def days_of_weeks(self) -> Optional[Sequence[str]]:
        """
        Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "days_of_weeks")

    @property
    @pulumi.getter(name="monthsOfYears")
    def months_of_years(self) -> Optional[Sequence[str]]:
        """
        Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "months_of_years")

    @property
    @pulumi.getter(name="scheduledBackupTimes")
    def scheduled_backup_times(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "scheduled_backup_times")

    @property
    @pulumi.getter(name="weeksOfMonths")
    def weeks_of_months(self) -> Optional[Sequence[str]]:
        """
        Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "weeks_of_months")


@pulumi.output_type
class BackupPolicyPostgresqlFlexibleServerRetentionRuleLifeCycle(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataStoreType":
            suggest = "data_store_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyPostgresqlFlexibleServerRetentionRuleLifeCycle. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyPostgresqlFlexibleServerRetentionRuleLifeCycle.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyPostgresqlFlexibleServerRetentionRuleLifeCycle.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_store_type: str,
                 duration: str):
        """
        :param str data_store_type: The type of data store. The only possible value is `VaultStore`. Changing this forces a new resource to be created.
        :param str duration: The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "data_store_type", data_store_type)
        pulumi.set(__self__, "duration", duration)

    @property
    @pulumi.getter(name="dataStoreType")
    def data_store_type(self) -> str:
        """
        The type of data store. The only possible value is `VaultStore`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "data_store_type")

    @property
    @pulumi.getter
    def duration(self) -> str:
        """
        The retention duration up to which the backups are to be retained in the data stores. It should follow `ISO 8601` duration format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration")


@pulumi.output_type
class BackupPolicyPostgresqlRetentionRule(dict):
    def __init__(__self__, *,
                 criteria: 'outputs.BackupPolicyPostgresqlRetentionRuleCriteria',
                 duration: str,
                 name: str,
                 priority: int):
        """
        :param 'BackupPolicyPostgresqlRetentionRuleCriteriaArgs' criteria: A `criteria` block as defined below. Changing this forces a new Backup Policy PostgreSQL to be created.
        :param str duration: Duration after which the backup is deleted. It should follow `ISO 8601` duration format. Changing this forces a new Backup Policy PostgreSQL to be created.
        :param str name: The name which should be used for this retention rule. Changing this forces a new Backup Policy PostgreSQL to be created.
        :param int priority: Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        pulumi.set(__self__, "criteria", criteria)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "priority", priority)

    @property
    @pulumi.getter
    def criteria(self) -> 'outputs.BackupPolicyPostgresqlRetentionRuleCriteria':
        """
        A `criteria` block as defined below. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        return pulumi.get(self, "criteria")

    @property
    @pulumi.getter
    def duration(self) -> str:
        """
        Duration after which the backup is deleted. It should follow `ISO 8601` duration format. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name which should be used for this retention rule. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def priority(self) -> int:
        """
        Specifies the priority of the rule. The priority number must be unique for each rule. The lower the priority number, the higher the priority of the rule. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        return pulumi.get(self, "priority")


@pulumi.output_type
class BackupPolicyPostgresqlRetentionRuleCriteria(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "absoluteCriteria":
            suggest = "absolute_criteria"
        elif key == "daysOfWeeks":
            suggest = "days_of_weeks"
        elif key == "monthsOfYears":
            suggest = "months_of_years"
        elif key == "scheduledBackupTimes":
            suggest = "scheduled_backup_times"
        elif key == "weeksOfMonths":
            suggest = "weeks_of_months"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupPolicyPostgresqlRetentionRuleCriteria. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupPolicyPostgresqlRetentionRuleCriteria.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupPolicyPostgresqlRetentionRuleCriteria.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 absolute_criteria: Optional[str] = None,
                 days_of_weeks: Optional[Sequence[str]] = None,
                 months_of_years: Optional[Sequence[str]] = None,
                 scheduled_backup_times: Optional[Sequence[str]] = None,
                 weeks_of_months: Optional[Sequence[str]] = None):
        """
        :param str absolute_criteria: Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new Backup Policy PostgreSQL to be created.
        :param Sequence[str] days_of_weeks: Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new Backup Policy PostgreSQL to be created.
        :param Sequence[str] months_of_years: Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new Backup Policy PostgreSQL to be created.
        :param Sequence[str] scheduled_backup_times: Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new Backup Policy PostgreSQL to be created.
        :param Sequence[str] weeks_of_months: Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        if absolute_criteria is not None:
            pulumi.set(__self__, "absolute_criteria", absolute_criteria)
        if days_of_weeks is not None:
            pulumi.set(__self__, "days_of_weeks", days_of_weeks)
        if months_of_years is not None:
            pulumi.set(__self__, "months_of_years", months_of_years)
        if scheduled_backup_times is not None:
            pulumi.set(__self__, "scheduled_backup_times", scheduled_backup_times)
        if weeks_of_months is not None:
            pulumi.set(__self__, "weeks_of_months", weeks_of_months)

    @property
    @pulumi.getter(name="absoluteCriteria")
    def absolute_criteria(self) -> Optional[str]:
        """
        Possible values are `AllBackup`, `FirstOfDay`, `FirstOfWeek`, `FirstOfMonth` and `FirstOfYear`. These values mean the first successful backup of the day/week/month/year. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        return pulumi.get(self, "absolute_criteria")

    @property
    @pulumi.getter(name="daysOfWeeks")
    def days_of_weeks(self) -> Optional[Sequence[str]]:
        """
        Possible values are `Monday`, `Tuesday`, `Thursday`, `Friday`, `Saturday` and `Sunday`. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        return pulumi.get(self, "days_of_weeks")

    @property
    @pulumi.getter(name="monthsOfYears")
    def months_of_years(self) -> Optional[Sequence[str]]:
        """
        Possible values are `January`, `February`, `March`, `April`, `May`, `June`, `July`, `August`, `September`, `October`, `November` and `December`. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        return pulumi.get(self, "months_of_years")

    @property
    @pulumi.getter(name="scheduledBackupTimes")
    def scheduled_backup_times(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of backup times for backup in the `RFC3339` format. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        return pulumi.get(self, "scheduled_backup_times")

    @property
    @pulumi.getter(name="weeksOfMonths")
    def weeks_of_months(self) -> Optional[Sequence[str]]:
        """
        Possible values are `First`, `Second`, `Third`, `Fourth` and `Last`. Changing this forces a new Backup Policy PostgreSQL to be created.
        """
        return pulumi.get(self, "weeks_of_months")


@pulumi.output_type
class BackupVaultIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BackupVaultIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BackupVaultIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BackupVaultIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this Backup Vault. The only possible value is `SystemAssigned`.
        :param str principal_id: The Principal ID for the Service Principal associated with the Identity of this Backup Vault.
        :param str tenant_id: The Tenant ID for the Service Principal associated with the Identity of this Backup Vault.
        """
        pulumi.set(__self__, "type", type)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Backup Vault. The only possible value is `SystemAssigned`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        """
        The Principal ID for the Service Principal associated with the Identity of this Backup Vault.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        The Tenant ID for the Service Principal associated with the Identity of this Backup Vault.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class GetBackupVaultIdentityResult(dict):
    def __init__(__self__, *,
                 principal_id: str,
                 tenant_id: str,
                 type: str):
        """
        :param str principal_id: The Principal ID of the System Assigned Managed Service Identity that is configured on this Backup Vault.
        :param str tenant_id: The Tenant ID of the System Assigned Managed Service Identity that is configured on this Backup Vault.
        :param str type: The type of Managed Service Identity that is configured on this Backup Vault.
        """
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "tenant_id", tenant_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> str:
        """
        The Principal ID of the System Assigned Managed Service Identity that is configured on this Backup Vault.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        The Tenant ID of the System Assigned Managed Service Identity that is configured on this Backup Vault.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of Managed Service Identity that is configured on this Backup Vault.
        """
        return pulumi.get(self, "type")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConfigurationArgs', 'Configuration']

@pulumi.input_type
class ConfigurationArgs:
    def __init__(__self__, *,
                 nginx_deployment_id: pulumi.Input[str],
                 root_file: pulumi.Input[str],
                 config_files: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationConfigFileArgs']]]] = None,
                 package_data: Optional[pulumi.Input[str]] = None,
                 protected_files: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationProtectedFileArgs']]]] = None):
        """
        The set of arguments for constructing a Configuration resource.
        :param pulumi.Input[str] nginx_deployment_id: The ID of the Nginx Deployment. Changing this forces a new Nginx Configuration to be created.
        :param pulumi.Input[str] root_file: Specifies the root file path of this Nginx Configuration.
        :param pulumi.Input[Sequence[pulumi.Input['ConfigurationConfigFileArgs']]] config_files: One or more `config_file` blocks as defined below.
        :param pulumi.Input[str] package_data: Specifies the package data for this configuration.
        :param pulumi.Input[Sequence[pulumi.Input['ConfigurationProtectedFileArgs']]] protected_files: One or more `protected_file` blocks with sensitive information as defined below. If specified `config_file` must also be specified.
        """
        pulumi.set(__self__, "nginx_deployment_id", nginx_deployment_id)
        pulumi.set(__self__, "root_file", root_file)
        if config_files is not None:
            pulumi.set(__self__, "config_files", config_files)
        if package_data is not None:
            pulumi.set(__self__, "package_data", package_data)
        if protected_files is not None:
            pulumi.set(__self__, "protected_files", protected_files)

    @property
    @pulumi.getter(name="nginxDeploymentId")
    def nginx_deployment_id(self) -> pulumi.Input[str]:
        """
        The ID of the Nginx Deployment. Changing this forces a new Nginx Configuration to be created.
        """
        return pulumi.get(self, "nginx_deployment_id")

    @nginx_deployment_id.setter
    def nginx_deployment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "nginx_deployment_id", value)

    @property
    @pulumi.getter(name="rootFile")
    def root_file(self) -> pulumi.Input[str]:
        """
        Specifies the root file path of this Nginx Configuration.
        """
        return pulumi.get(self, "root_file")

    @root_file.setter
    def root_file(self, value: pulumi.Input[str]):
        pulumi.set(self, "root_file", value)

    @property
    @pulumi.getter(name="configFiles")
    def config_files(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationConfigFileArgs']]]]:
        """
        One or more `config_file` blocks as defined below.
        """
        return pulumi.get(self, "config_files")

    @config_files.setter
    def config_files(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationConfigFileArgs']]]]):
        pulumi.set(self, "config_files", value)

    @property
    @pulumi.getter(name="packageData")
    def package_data(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the package data for this configuration.
        """
        return pulumi.get(self, "package_data")

    @package_data.setter
    def package_data(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_data", value)

    @property
    @pulumi.getter(name="protectedFiles")
    def protected_files(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationProtectedFileArgs']]]]:
        """
        One or more `protected_file` blocks with sensitive information as defined below. If specified `config_file` must also be specified.
        """
        return pulumi.get(self, "protected_files")

    @protected_files.setter
    def protected_files(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationProtectedFileArgs']]]]):
        pulumi.set(self, "protected_files", value)


@pulumi.input_type
class _ConfigurationState:
    def __init__(__self__, *,
                 config_files: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationConfigFileArgs']]]] = None,
                 nginx_deployment_id: Optional[pulumi.Input[str]] = None,
                 package_data: Optional[pulumi.Input[str]] = None,
                 protected_files: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationProtectedFileArgs']]]] = None,
                 root_file: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Configuration resources.
        :param pulumi.Input[Sequence[pulumi.Input['ConfigurationConfigFileArgs']]] config_files: One or more `config_file` blocks as defined below.
        :param pulumi.Input[str] nginx_deployment_id: The ID of the Nginx Deployment. Changing this forces a new Nginx Configuration to be created.
        :param pulumi.Input[str] package_data: Specifies the package data for this configuration.
        :param pulumi.Input[Sequence[pulumi.Input['ConfigurationProtectedFileArgs']]] protected_files: One or more `protected_file` blocks with sensitive information as defined below. If specified `config_file` must also be specified.
        :param pulumi.Input[str] root_file: Specifies the root file path of this Nginx Configuration.
        """
        if config_files is not None:
            pulumi.set(__self__, "config_files", config_files)
        if nginx_deployment_id is not None:
            pulumi.set(__self__, "nginx_deployment_id", nginx_deployment_id)
        if package_data is not None:
            pulumi.set(__self__, "package_data", package_data)
        if protected_files is not None:
            pulumi.set(__self__, "protected_files", protected_files)
        if root_file is not None:
            pulumi.set(__self__, "root_file", root_file)

    @property
    @pulumi.getter(name="configFiles")
    def config_files(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationConfigFileArgs']]]]:
        """
        One or more `config_file` blocks as defined below.
        """
        return pulumi.get(self, "config_files")

    @config_files.setter
    def config_files(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationConfigFileArgs']]]]):
        pulumi.set(self, "config_files", value)

    @property
    @pulumi.getter(name="nginxDeploymentId")
    def nginx_deployment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Nginx Deployment. Changing this forces a new Nginx Configuration to be created.
        """
        return pulumi.get(self, "nginx_deployment_id")

    @nginx_deployment_id.setter
    def nginx_deployment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nginx_deployment_id", value)

    @property
    @pulumi.getter(name="packageData")
    def package_data(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the package data for this configuration.
        """
        return pulumi.get(self, "package_data")

    @package_data.setter
    def package_data(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_data", value)

    @property
    @pulumi.getter(name="protectedFiles")
    def protected_files(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationProtectedFileArgs']]]]:
        """
        One or more `protected_file` blocks with sensitive information as defined below. If specified `config_file` must also be specified.
        """
        return pulumi.get(self, "protected_files")

    @protected_files.setter
    def protected_files(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationProtectedFileArgs']]]]):
        pulumi.set(self, "protected_files", value)

    @property
    @pulumi.getter(name="rootFile")
    def root_file(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the root file path of this Nginx Configuration.
        """
        return pulumi.get(self, "root_file")

    @root_file.setter
    def root_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "root_file", value)


class Configuration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationConfigFileArgs', 'ConfigurationConfigFileArgsDict']]]]] = None,
                 nginx_deployment_id: Optional[pulumi.Input[str]] = None,
                 package_data: Optional[pulumi.Input[str]] = None,
                 protected_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationProtectedFileArgs', 'ConfigurationProtectedFileArgsDict']]]]] = None,
                 root_file: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages the configuration for a Nginx Deployment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_std as std

        example = azure.core.ResourceGroup("example",
            name="example-rg",
            location="West Europe")
        example_public_ip = azure.network.PublicIp("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            allocation_method="Static",
            sku="Standard",
            tags={
                "environment": "Production",
            })
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-vnet",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"],
            delegations=[{
                "name": "delegation",
                "service_delegation": {
                    "name": "NGINX.NGINXPLUS/nginxDeployments",
                    "actions": ["Microsoft.Network/virtualNetworks/subnets/join/action"],
                },
            }])
        example_deployment = azure.nginx.Deployment("example",
            name="example-nginx",
            resource_group_name=example.name,
            sku="publicpreview_Monthly_gmz7xq9ge3py",
            location=example.location,
            diagnose_support_enabled=True,
            frontend_public={
                "ip_addresses": [example_public_ip.id],
            },
            network_interfaces=[{
                "subnet_id": example_subnet.id,
            }])
        example_configuration = azure.nginx.Configuration("example",
            nginx_deployment_id=example_deployment.id,
            root_file="/etc/nginx/nginx.conf",
            config_files=[
                {
                    "content": std.base64encode(input=\"\"\"http {
            server {
                listen 80;
                location / {
                    default_type text/html;
                    return 200 '<!doctype html><html lang="en"><head></head><body>
                        <div>this one will be updated</div>
                        <div>at 10:38 am</div>
                    </body></html>';
                }
                include site/*.conf;
            }
        }
        \"\"\").result,
                    "virtual_path": "/etc/nginx/nginx.conf",
                },
                {
                    "content": std.base64encode(input=\"\"\"location /bbb {
         default_type text/html;
         return 200 '<!doctype html><html lang="en"><head></head><body>
          <div>this one will be updated</div>
          <div>at 10:38 am</div>
         </body></html>';
        }
        \"\"\").result,
                    "virtual_path": "/etc/nginx/site/b.conf",
                },
            ])
        ```

        ## Import

        An Nginx Configuration can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:nginx/configuration:Configuration example /subscriptions/12345678-1234-9876-4563-123456789012/resourceGroups/group1/providers/Nginx.NginxPlus/nginxDeployments/dep1/configurations/default
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationConfigFileArgs', 'ConfigurationConfigFileArgsDict']]]] config_files: One or more `config_file` blocks as defined below.
        :param pulumi.Input[str] nginx_deployment_id: The ID of the Nginx Deployment. Changing this forces a new Nginx Configuration to be created.
        :param pulumi.Input[str] package_data: Specifies the package data for this configuration.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationProtectedFileArgs', 'ConfigurationProtectedFileArgsDict']]]] protected_files: One or more `protected_file` blocks with sensitive information as defined below. If specified `config_file` must also be specified.
        :param pulumi.Input[str] root_file: Specifies the root file path of this Nginx Configuration.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages the configuration for a Nginx Deployment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_std as std

        example = azure.core.ResourceGroup("example",
            name="example-rg",
            location="West Europe")
        example_public_ip = azure.network.PublicIp("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            allocation_method="Static",
            sku="Standard",
            tags={
                "environment": "Production",
            })
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-vnet",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"],
            delegations=[{
                "name": "delegation",
                "service_delegation": {
                    "name": "NGINX.NGINXPLUS/nginxDeployments",
                    "actions": ["Microsoft.Network/virtualNetworks/subnets/join/action"],
                },
            }])
        example_deployment = azure.nginx.Deployment("example",
            name="example-nginx",
            resource_group_name=example.name,
            sku="publicpreview_Monthly_gmz7xq9ge3py",
            location=example.location,
            diagnose_support_enabled=True,
            frontend_public={
                "ip_addresses": [example_public_ip.id],
            },
            network_interfaces=[{
                "subnet_id": example_subnet.id,
            }])
        example_configuration = azure.nginx.Configuration("example",
            nginx_deployment_id=example_deployment.id,
            root_file="/etc/nginx/nginx.conf",
            config_files=[
                {
                    "content": std.base64encode(input=\"\"\"http {
            server {
                listen 80;
                location / {
                    default_type text/html;
                    return 200 '<!doctype html><html lang="en"><head></head><body>
                        <div>this one will be updated</div>
                        <div>at 10:38 am</div>
                    </body></html>';
                }
                include site/*.conf;
            }
        }
        \"\"\").result,
                    "virtual_path": "/etc/nginx/nginx.conf",
                },
                {
                    "content": std.base64encode(input=\"\"\"location /bbb {
         default_type text/html;
         return 200 '<!doctype html><html lang="en"><head></head><body>
          <div>this one will be updated</div>
          <div>at 10:38 am</div>
         </body></html>';
        }
        \"\"\").result,
                    "virtual_path": "/etc/nginx/site/b.conf",
                },
            ])
        ```

        ## Import

        An Nginx Configuration can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:nginx/configuration:Configuration example /subscriptions/12345678-1234-9876-4563-123456789012/resourceGroups/group1/providers/Nginx.NginxPlus/nginxDeployments/dep1/configurations/default
        ```

        :param str resource_name: The name of the resource.
        :param ConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationConfigFileArgs', 'ConfigurationConfigFileArgsDict']]]]] = None,
                 nginx_deployment_id: Optional[pulumi.Input[str]] = None,
                 package_data: Optional[pulumi.Input[str]] = None,
                 protected_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationProtectedFileArgs', 'ConfigurationProtectedFileArgsDict']]]]] = None,
                 root_file: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConfigurationArgs.__new__(ConfigurationArgs)

            __props__.__dict__["config_files"] = config_files
            if nginx_deployment_id is None and not opts.urn:
                raise TypeError("Missing required property 'nginx_deployment_id'")
            __props__.__dict__["nginx_deployment_id"] = nginx_deployment_id
            __props__.__dict__["package_data"] = package_data
            __props__.__dict__["protected_files"] = protected_files
            if root_file is None and not opts.urn:
                raise TypeError("Missing required property 'root_file'")
            __props__.__dict__["root_file"] = root_file
        super(Configuration, __self__).__init__(
            'azure:nginx/configuration:Configuration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationConfigFileArgs', 'ConfigurationConfigFileArgsDict']]]]] = None,
            nginx_deployment_id: Optional[pulumi.Input[str]] = None,
            package_data: Optional[pulumi.Input[str]] = None,
            protected_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationProtectedFileArgs', 'ConfigurationProtectedFileArgsDict']]]]] = None,
            root_file: Optional[pulumi.Input[str]] = None) -> 'Configuration':
        """
        Get an existing Configuration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationConfigFileArgs', 'ConfigurationConfigFileArgsDict']]]] config_files: One or more `config_file` blocks as defined below.
        :param pulumi.Input[str] nginx_deployment_id: The ID of the Nginx Deployment. Changing this forces a new Nginx Configuration to be created.
        :param pulumi.Input[str] package_data: Specifies the package data for this configuration.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConfigurationProtectedFileArgs', 'ConfigurationProtectedFileArgsDict']]]] protected_files: One or more `protected_file` blocks with sensitive information as defined below. If specified `config_file` must also be specified.
        :param pulumi.Input[str] root_file: Specifies the root file path of this Nginx Configuration.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConfigurationState.__new__(_ConfigurationState)

        __props__.__dict__["config_files"] = config_files
        __props__.__dict__["nginx_deployment_id"] = nginx_deployment_id
        __props__.__dict__["package_data"] = package_data
        __props__.__dict__["protected_files"] = protected_files
        __props__.__dict__["root_file"] = root_file
        return Configuration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configFiles")
    def config_files(self) -> pulumi.Output[Optional[Sequence['outputs.ConfigurationConfigFile']]]:
        """
        One or more `config_file` blocks as defined below.
        """
        return pulumi.get(self, "config_files")

    @property
    @pulumi.getter(name="nginxDeploymentId")
    def nginx_deployment_id(self) -> pulumi.Output[str]:
        """
        The ID of the Nginx Deployment. Changing this forces a new Nginx Configuration to be created.
        """
        return pulumi.get(self, "nginx_deployment_id")

    @property
    @pulumi.getter(name="packageData")
    def package_data(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the package data for this configuration.
        """
        return pulumi.get(self, "package_data")

    @property
    @pulumi.getter(name="protectedFiles")
    def protected_files(self) -> pulumi.Output[Optional[Sequence['outputs.ConfigurationProtectedFile']]]:
        """
        One or more `protected_file` blocks with sensitive information as defined below. If specified `config_file` must also be specified.
        """
        return pulumi.get(self, "protected_files")

    @property
    @pulumi.getter(name="rootFile")
    def root_file(self) -> pulumi.Output[str]:
        """
        Specifies the root file path of this Nginx Configuration.
        """
        return pulumi.get(self, "root_file")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSecretsResult',
    'AwaitableGetSecretsResult',
    'get_secrets',
    'get_secrets_output',
]

@pulumi.output_type
class GetSecretsResult:
    """
    A collection of values returned by getSecrets.
    """
    def __init__(__self__, id=None, key_vault_id=None, names=None, secrets=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_vault_id and not isinstance(key_vault_id, str):
            raise TypeError("Expected argument 'key_vault_id' to be a str")
        pulumi.set(__self__, "key_vault_id", key_vault_id)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if secrets and not isinstance(secrets, list):
            raise TypeError("Expected argument 'secrets' to be a list")
        pulumi.set(__self__, "secrets", secrets)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keyVaultId")
    def key_vault_id(self) -> str:
        return pulumi.get(self, "key_vault_id")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        List containing names of secrets that exist in this Key Vault.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter
    def secrets(self) -> Sequence['outputs.GetSecretsSecretResult']:
        """
        One or more `secrets` blocks as defined below.
        """
        return pulumi.get(self, "secrets")


class AwaitableGetSecretsResult(GetSecretsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecretsResult(
            id=self.id,
            key_vault_id=self.key_vault_id,
            names=self.names,
            secrets=self.secrets)


def get_secrets(key_vault_id: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecretsResult:
    """
    Use this data source to retrieve a list of secret names from an existing Key Vault Secret.


    :param str key_vault_id: Specifies the ID of the Key Vault instance to fetch secret names from, available on the `keyvault.KeyVault` Data Source / Resource.
           
           **NOTE:** The vault must be in the same subscription as the provider. If the vault is in another subscription, you must create an aliased provider for that subscription.
    """
    __args__ = dict()
    __args__['keyVaultId'] = key_vault_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:keyvault/getSecrets:getSecrets', __args__, opts=opts, typ=GetSecretsResult).value

    return AwaitableGetSecretsResult(
        id=pulumi.get(__ret__, 'id'),
        key_vault_id=pulumi.get(__ret__, 'key_vault_id'),
        names=pulumi.get(__ret__, 'names'),
        secrets=pulumi.get(__ret__, 'secrets'))
def get_secrets_output(key_vault_id: Optional[pulumi.Input[str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecretsResult]:
    """
    Use this data source to retrieve a list of secret names from an existing Key Vault Secret.


    :param str key_vault_id: Specifies the ID of the Key Vault instance to fetch secret names from, available on the `keyvault.KeyVault` Data Source / Resource.
           
           **NOTE:** The vault must be in the same subscription as the provider. If the vault is in another subscription, you must create an aliased provider for that subscription.
    """
    __args__ = dict()
    __args__['keyVaultId'] = key_vault_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:keyvault/getSecrets:getSecrets', __args__, opts=opts, typ=GetSecretsResult)
    return __ret__.apply(lambda __response__: GetSecretsResult(
        id=pulumi.get(__response__, 'id'),
        key_vault_id=pulumi.get(__response__, 'key_vault_id'),
        names=pulumi.get(__response__, 'names'),
        secrets=pulumi.get(__response__, 'secrets')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FluxConfigurationArgs', 'FluxConfiguration']

@pulumi.input_type
class FluxConfigurationArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[str],
                 kustomizations: pulumi.Input[Sequence[pulumi.Input['FluxConfigurationKustomizationArgs']]],
                 namespace: pulumi.Input[str],
                 blob_storage: Optional[pulumi.Input['FluxConfigurationBlobStorageArgs']] = None,
                 bucket: Optional[pulumi.Input['FluxConfigurationBucketArgs']] = None,
                 continuous_reconciliation_enabled: Optional[pulumi.Input[bool]] = None,
                 git_repository: Optional[pulumi.Input['FluxConfigurationGitRepositoryArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 scope: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a FluxConfiguration resource.
        :param pulumi.Input[str] cluster_id: Specifies the Cluster ID. Changing this forces a new Kubernetes Cluster Extension to be created.
        :param pulumi.Input[Sequence[pulumi.Input['FluxConfigurationKustomizationArgs']]] kustomizations: A `kustomizations` block as defined below.
        :param pulumi.Input[str] namespace: Specifies the namespace to which this configuration is installed to. Changing this forces a new Kubernetes Flux Configuration to be created.
        :param pulumi.Input['FluxConfigurationBlobStorageArgs'] blob_storage: An `blob_storage` block as defined below.
        :param pulumi.Input['FluxConfigurationBucketArgs'] bucket: A `bucket` block as defined below.
        :param pulumi.Input[bool] continuous_reconciliation_enabled: Whether the configuration will keep its reconciliation of its kustomizations and sources with the repository. Defaults to `true`.
        :param pulumi.Input['FluxConfigurationGitRepositoryArgs'] git_repository: A `git_repository` block as defined below.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Kubernetes Flux Configuration. Changing this forces a new Kubernetes Flux Configuration to be created.
        :param pulumi.Input[str] scope: Specifies the scope at which the operator will be installed. Possible values are `cluster` and `namespace`. Defaults to `namespace`. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "kustomizations", kustomizations)
        pulumi.set(__self__, "namespace", namespace)
        if blob_storage is not None:
            pulumi.set(__self__, "blob_storage", blob_storage)
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if continuous_reconciliation_enabled is not None:
            pulumi.set(__self__, "continuous_reconciliation_enabled", continuous_reconciliation_enabled)
        if git_repository is not None:
            pulumi.set(__self__, "git_repository", git_repository)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[str]:
        """
        Specifies the Cluster ID. Changing this forces a new Kubernetes Cluster Extension to be created.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def kustomizations(self) -> pulumi.Input[Sequence[pulumi.Input['FluxConfigurationKustomizationArgs']]]:
        """
        A `kustomizations` block as defined below.
        """
        return pulumi.get(self, "kustomizations")

    @kustomizations.setter
    def kustomizations(self, value: pulumi.Input[Sequence[pulumi.Input['FluxConfigurationKustomizationArgs']]]):
        pulumi.set(self, "kustomizations", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        Specifies the namespace to which this configuration is installed to. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="blobStorage")
    def blob_storage(self) -> Optional[pulumi.Input['FluxConfigurationBlobStorageArgs']]:
        """
        An `blob_storage` block as defined below.
        """
        return pulumi.get(self, "blob_storage")

    @blob_storage.setter
    def blob_storage(self, value: Optional[pulumi.Input['FluxConfigurationBlobStorageArgs']]):
        pulumi.set(self, "blob_storage", value)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input['FluxConfigurationBucketArgs']]:
        """
        A `bucket` block as defined below.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input['FluxConfigurationBucketArgs']]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="continuousReconciliationEnabled")
    def continuous_reconciliation_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the configuration will keep its reconciliation of its kustomizations and sources with the repository. Defaults to `true`.
        """
        return pulumi.get(self, "continuous_reconciliation_enabled")

    @continuous_reconciliation_enabled.setter
    def continuous_reconciliation_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "continuous_reconciliation_enabled", value)

    @property
    @pulumi.getter(name="gitRepository")
    def git_repository(self) -> Optional[pulumi.Input['FluxConfigurationGitRepositoryArgs']]:
        """
        A `git_repository` block as defined below.
        """
        return pulumi.get(self, "git_repository")

    @git_repository.setter
    def git_repository(self, value: Optional[pulumi.Input['FluxConfigurationGitRepositoryArgs']]):
        pulumi.set(self, "git_repository", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name which should be used for this Kubernetes Flux Configuration. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def scope(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the scope at which the operator will be installed. Possible values are `cluster` and `namespace`. Defaults to `namespace`. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scope", value)


@pulumi.input_type
class _FluxConfigurationState:
    def __init__(__self__, *,
                 blob_storage: Optional[pulumi.Input['FluxConfigurationBlobStorageArgs']] = None,
                 bucket: Optional[pulumi.Input['FluxConfigurationBucketArgs']] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 continuous_reconciliation_enabled: Optional[pulumi.Input[bool]] = None,
                 git_repository: Optional[pulumi.Input['FluxConfigurationGitRepositoryArgs']] = None,
                 kustomizations: Optional[pulumi.Input[Sequence[pulumi.Input['FluxConfigurationKustomizationArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 scope: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering FluxConfiguration resources.
        :param pulumi.Input['FluxConfigurationBlobStorageArgs'] blob_storage: An `blob_storage` block as defined below.
        :param pulumi.Input['FluxConfigurationBucketArgs'] bucket: A `bucket` block as defined below.
        :param pulumi.Input[str] cluster_id: Specifies the Cluster ID. Changing this forces a new Kubernetes Cluster Extension to be created.
        :param pulumi.Input[bool] continuous_reconciliation_enabled: Whether the configuration will keep its reconciliation of its kustomizations and sources with the repository. Defaults to `true`.
        :param pulumi.Input['FluxConfigurationGitRepositoryArgs'] git_repository: A `git_repository` block as defined below.
        :param pulumi.Input[Sequence[pulumi.Input['FluxConfigurationKustomizationArgs']]] kustomizations: A `kustomizations` block as defined below.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Kubernetes Flux Configuration. Changing this forces a new Kubernetes Flux Configuration to be created.
        :param pulumi.Input[str] namespace: Specifies the namespace to which this configuration is installed to. Changing this forces a new Kubernetes Flux Configuration to be created.
        :param pulumi.Input[str] scope: Specifies the scope at which the operator will be installed. Possible values are `cluster` and `namespace`. Defaults to `namespace`. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        if blob_storage is not None:
            pulumi.set(__self__, "blob_storage", blob_storage)
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if continuous_reconciliation_enabled is not None:
            pulumi.set(__self__, "continuous_reconciliation_enabled", continuous_reconciliation_enabled)
        if git_repository is not None:
            pulumi.set(__self__, "git_repository", git_repository)
        if kustomizations is not None:
            pulumi.set(__self__, "kustomizations", kustomizations)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)

    @property
    @pulumi.getter(name="blobStorage")
    def blob_storage(self) -> Optional[pulumi.Input['FluxConfigurationBlobStorageArgs']]:
        """
        An `blob_storage` block as defined below.
        """
        return pulumi.get(self, "blob_storage")

    @blob_storage.setter
    def blob_storage(self, value: Optional[pulumi.Input['FluxConfigurationBlobStorageArgs']]):
        pulumi.set(self, "blob_storage", value)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input['FluxConfigurationBucketArgs']]:
        """
        A `bucket` block as defined below.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input['FluxConfigurationBucketArgs']]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Cluster ID. Changing this forces a new Kubernetes Cluster Extension to be created.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="continuousReconciliationEnabled")
    def continuous_reconciliation_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the configuration will keep its reconciliation of its kustomizations and sources with the repository. Defaults to `true`.
        """
        return pulumi.get(self, "continuous_reconciliation_enabled")

    @continuous_reconciliation_enabled.setter
    def continuous_reconciliation_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "continuous_reconciliation_enabled", value)

    @property
    @pulumi.getter(name="gitRepository")
    def git_repository(self) -> Optional[pulumi.Input['FluxConfigurationGitRepositoryArgs']]:
        """
        A `git_repository` block as defined below.
        """
        return pulumi.get(self, "git_repository")

    @git_repository.setter
    def git_repository(self, value: Optional[pulumi.Input['FluxConfigurationGitRepositoryArgs']]):
        pulumi.set(self, "git_repository", value)

    @property
    @pulumi.getter
    def kustomizations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FluxConfigurationKustomizationArgs']]]]:
        """
        A `kustomizations` block as defined below.
        """
        return pulumi.get(self, "kustomizations")

    @kustomizations.setter
    def kustomizations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FluxConfigurationKustomizationArgs']]]]):
        pulumi.set(self, "kustomizations", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name which should be used for this Kubernetes Flux Configuration. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the namespace to which this configuration is installed to. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def scope(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the scope at which the operator will be installed. Possible values are `cluster` and `namespace`. Defaults to `namespace`. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scope", value)


class FluxConfiguration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 blob_storage: Optional[pulumi.Input[Union['FluxConfigurationBlobStorageArgs', 'FluxConfigurationBlobStorageArgsDict']]] = None,
                 bucket: Optional[pulumi.Input[Union['FluxConfigurationBucketArgs', 'FluxConfigurationBucketArgsDict']]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 continuous_reconciliation_enabled: Optional[pulumi.Input[bool]] = None,
                 git_repository: Optional[pulumi.Input[Union['FluxConfigurationGitRepositoryArgs', 'FluxConfigurationGitRepositoryArgsDict']]] = None,
                 kustomizations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FluxConfigurationKustomizationArgs', 'FluxConfigurationKustomizationArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 scope: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Kubernetes Flux Configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_kubernetes_cluster = azure.containerservice.KubernetesCluster("example",
            name="example-aks",
            location="West Europe",
            resource_group_name=example.name,
            dns_prefix="example-aks",
            default_node_pool={
                "name": "default",
                "node_count": 1,
                "vm_size": "Standard_DS2_v2",
            },
            identity={
                "type": "SystemAssigned",
            })
        example_kubernetes_cluster_extension = azure.containerservice.KubernetesClusterExtension("example",
            name="example-ext",
            cluster_id=test["id"],
            extension_type="microsoft.flux")
        example_flux_configuration = azure.containerservice.FluxConfiguration("example",
            name="example-fc",
            cluster_id=test["id"],
            namespace="flux",
            git_repository={
                "url": "https://github.com/Azure/arc-k8s-demo",
                "reference_type": "branch",
                "reference_value": "main",
            },
            kustomizations=[{
                "name": "kustomization-1",
                "post_build": {
                    "substitute": {
                        "example_var": "substitute_with_this",
                    },
                    "substitute_froms": [{
                        "kind": "ConfigMap",
                        "name": "example-configmap",
                    }],
                },
            }],
            opts = pulumi.ResourceOptions(depends_on=[example_kubernetes_cluster_extension]))
        ```

        ## Import

        Kubernetes Flux Configuration can be imported using the `resource id` for different `cluster_resource_name`, e.g.

        ```sh
        $ pulumi import azure:containerservice/fluxConfiguration:FluxConfiguration example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.ContainerService/managedClusters/cluster1/providers/Microsoft.KubernetesConfiguration/fluxConfigurations/fluxConfiguration1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FluxConfigurationBlobStorageArgs', 'FluxConfigurationBlobStorageArgsDict']] blob_storage: An `blob_storage` block as defined below.
        :param pulumi.Input[Union['FluxConfigurationBucketArgs', 'FluxConfigurationBucketArgsDict']] bucket: A `bucket` block as defined below.
        :param pulumi.Input[str] cluster_id: Specifies the Cluster ID. Changing this forces a new Kubernetes Cluster Extension to be created.
        :param pulumi.Input[bool] continuous_reconciliation_enabled: Whether the configuration will keep its reconciliation of its kustomizations and sources with the repository. Defaults to `true`.
        :param pulumi.Input[Union['FluxConfigurationGitRepositoryArgs', 'FluxConfigurationGitRepositoryArgsDict']] git_repository: A `git_repository` block as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['FluxConfigurationKustomizationArgs', 'FluxConfigurationKustomizationArgsDict']]]] kustomizations: A `kustomizations` block as defined below.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Kubernetes Flux Configuration. Changing this forces a new Kubernetes Flux Configuration to be created.
        :param pulumi.Input[str] namespace: Specifies the namespace to which this configuration is installed to. Changing this forces a new Kubernetes Flux Configuration to be created.
        :param pulumi.Input[str] scope: Specifies the scope at which the operator will be installed. Possible values are `cluster` and `namespace`. Defaults to `namespace`. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FluxConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Kubernetes Flux Configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_kubernetes_cluster = azure.containerservice.KubernetesCluster("example",
            name="example-aks",
            location="West Europe",
            resource_group_name=example.name,
            dns_prefix="example-aks",
            default_node_pool={
                "name": "default",
                "node_count": 1,
                "vm_size": "Standard_DS2_v2",
            },
            identity={
                "type": "SystemAssigned",
            })
        example_kubernetes_cluster_extension = azure.containerservice.KubernetesClusterExtension("example",
            name="example-ext",
            cluster_id=test["id"],
            extension_type="microsoft.flux")
        example_flux_configuration = azure.containerservice.FluxConfiguration("example",
            name="example-fc",
            cluster_id=test["id"],
            namespace="flux",
            git_repository={
                "url": "https://github.com/Azure/arc-k8s-demo",
                "reference_type": "branch",
                "reference_value": "main",
            },
            kustomizations=[{
                "name": "kustomization-1",
                "post_build": {
                    "substitute": {
                        "example_var": "substitute_with_this",
                    },
                    "substitute_froms": [{
                        "kind": "ConfigMap",
                        "name": "example-configmap",
                    }],
                },
            }],
            opts = pulumi.ResourceOptions(depends_on=[example_kubernetes_cluster_extension]))
        ```

        ## Import

        Kubernetes Flux Configuration can be imported using the `resource id` for different `cluster_resource_name`, e.g.

        ```sh
        $ pulumi import azure:containerservice/fluxConfiguration:FluxConfiguration example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.ContainerService/managedClusters/cluster1/providers/Microsoft.KubernetesConfiguration/fluxConfigurations/fluxConfiguration1
        ```

        :param str resource_name: The name of the resource.
        :param FluxConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FluxConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 blob_storage: Optional[pulumi.Input[Union['FluxConfigurationBlobStorageArgs', 'FluxConfigurationBlobStorageArgsDict']]] = None,
                 bucket: Optional[pulumi.Input[Union['FluxConfigurationBucketArgs', 'FluxConfigurationBucketArgsDict']]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 continuous_reconciliation_enabled: Optional[pulumi.Input[bool]] = None,
                 git_repository: Optional[pulumi.Input[Union['FluxConfigurationGitRepositoryArgs', 'FluxConfigurationGitRepositoryArgsDict']]] = None,
                 kustomizations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FluxConfigurationKustomizationArgs', 'FluxConfigurationKustomizationArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 scope: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FluxConfigurationArgs.__new__(FluxConfigurationArgs)

            __props__.__dict__["blob_storage"] = blob_storage
            __props__.__dict__["bucket"] = bucket
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["continuous_reconciliation_enabled"] = continuous_reconciliation_enabled
            __props__.__dict__["git_repository"] = git_repository
            if kustomizations is None and not opts.urn:
                raise TypeError("Missing required property 'kustomizations'")
            __props__.__dict__["kustomizations"] = kustomizations
            __props__.__dict__["name"] = name
            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["scope"] = scope
        super(FluxConfiguration, __self__).__init__(
            'azure:containerservice/fluxConfiguration:FluxConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            blob_storage: Optional[pulumi.Input[Union['FluxConfigurationBlobStorageArgs', 'FluxConfigurationBlobStorageArgsDict']]] = None,
            bucket: Optional[pulumi.Input[Union['FluxConfigurationBucketArgs', 'FluxConfigurationBucketArgsDict']]] = None,
            cluster_id: Optional[pulumi.Input[str]] = None,
            continuous_reconciliation_enabled: Optional[pulumi.Input[bool]] = None,
            git_repository: Optional[pulumi.Input[Union['FluxConfigurationGitRepositoryArgs', 'FluxConfigurationGitRepositoryArgsDict']]] = None,
            kustomizations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FluxConfigurationKustomizationArgs', 'FluxConfigurationKustomizationArgsDict']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            scope: Optional[pulumi.Input[str]] = None) -> 'FluxConfiguration':
        """
        Get an existing FluxConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FluxConfigurationBlobStorageArgs', 'FluxConfigurationBlobStorageArgsDict']] blob_storage: An `blob_storage` block as defined below.
        :param pulumi.Input[Union['FluxConfigurationBucketArgs', 'FluxConfigurationBucketArgsDict']] bucket: A `bucket` block as defined below.
        :param pulumi.Input[str] cluster_id: Specifies the Cluster ID. Changing this forces a new Kubernetes Cluster Extension to be created.
        :param pulumi.Input[bool] continuous_reconciliation_enabled: Whether the configuration will keep its reconciliation of its kustomizations and sources with the repository. Defaults to `true`.
        :param pulumi.Input[Union['FluxConfigurationGitRepositoryArgs', 'FluxConfigurationGitRepositoryArgsDict']] git_repository: A `git_repository` block as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['FluxConfigurationKustomizationArgs', 'FluxConfigurationKustomizationArgsDict']]]] kustomizations: A `kustomizations` block as defined below.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Kubernetes Flux Configuration. Changing this forces a new Kubernetes Flux Configuration to be created.
        :param pulumi.Input[str] namespace: Specifies the namespace to which this configuration is installed to. Changing this forces a new Kubernetes Flux Configuration to be created.
        :param pulumi.Input[str] scope: Specifies the scope at which the operator will be installed. Possible values are `cluster` and `namespace`. Defaults to `namespace`. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FluxConfigurationState.__new__(_FluxConfigurationState)

        __props__.__dict__["blob_storage"] = blob_storage
        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["continuous_reconciliation_enabled"] = continuous_reconciliation_enabled
        __props__.__dict__["git_repository"] = git_repository
        __props__.__dict__["kustomizations"] = kustomizations
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["scope"] = scope
        return FluxConfiguration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="blobStorage")
    def blob_storage(self) -> pulumi.Output[Optional['outputs.FluxConfigurationBlobStorage']]:
        """
        An `blob_storage` block as defined below.
        """
        return pulumi.get(self, "blob_storage")

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[Optional['outputs.FluxConfigurationBucket']]:
        """
        A `bucket` block as defined below.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[str]:
        """
        Specifies the Cluster ID. Changing this forces a new Kubernetes Cluster Extension to be created.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="continuousReconciliationEnabled")
    def continuous_reconciliation_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the configuration will keep its reconciliation of its kustomizations and sources with the repository. Defaults to `true`.
        """
        return pulumi.get(self, "continuous_reconciliation_enabled")

    @property
    @pulumi.getter(name="gitRepository")
    def git_repository(self) -> pulumi.Output[Optional['outputs.FluxConfigurationGitRepository']]:
        """
        A `git_repository` block as defined below.
        """
        return pulumi.get(self, "git_repository")

    @property
    @pulumi.getter
    def kustomizations(self) -> pulumi.Output[Sequence['outputs.FluxConfigurationKustomization']]:
        """
        A `kustomizations` block as defined below.
        """
        return pulumi.get(self, "kustomizations")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Specifies the name which should be used for this Kubernetes Flux Configuration. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[str]:
        """
        Specifies the namespace to which this configuration is installed to. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def scope(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the scope at which the operator will be installed. Possible values are `cluster` and `namespace`. Defaults to `namespace`. Changing this forces a new Kubernetes Flux Configuration to be created.
        """
        return pulumi.get(self, "scope")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .cluster_trusted_access_role_binding import *
from .connected_registry import *
from .fleet_member import *
from .fleet_update_run import *
from .fleet_update_strategy import *
from .flux_configuration import *
from .get_cluster_node_pool import *
from .get_fleet_manager import *
from .get_group import *
from .get_kubernetes_cluster import *
from .get_kubernetes_node_pool_snapshot import *
from .get_kubernetes_service_versions import *
from .get_registry import *
from .get_registry_cache_rule import *
from .get_registry_scope_map import *
from .get_registry_token import *
from .group import *
from .kubernetes_cluster import *
from .kubernetes_cluster_extension import *
from .kubernetes_cluster_node_pool import *
from .kubernetes_fleet_manager import *
from .registry import *
from .registry_agent_pool import *
from .registry_cache_rule import *
from .registry_credential_set import *
from .registry_scope_map import *
from .registry_task import *
from .registry_task_schedule_run_now import *
from .registry_token import *
from .registry_webhook import *
from .registry_webook import *
from .token_password import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ChannelDirectLineSite',
    'ChannelFacebookPage',
    'ChannelLineLineChannel',
    'ChannelWebChatSite',
]

@pulumi.output_type
class ChannelDirectLineSite(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "endpointParametersEnabled":
            suggest = "endpoint_parameters_enabled"
        elif key == "enhancedAuthenticationEnabled":
            suggest = "enhanced_authentication_enabled"
        elif key == "storageEnabled":
            suggest = "storage_enabled"
        elif key == "trustedOrigins":
            suggest = "trusted_origins"
        elif key == "userUploadEnabled":
            suggest = "user_upload_enabled"
        elif key == "v1Allowed":
            suggest = "v1_allowed"
        elif key == "v3Allowed":
            suggest = "v3_allowed"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ChannelDirectLineSite. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ChannelDirectLineSite.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ChannelDirectLineSite.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: str,
                 enabled: Optional[bool] = None,
                 endpoint_parameters_enabled: Optional[bool] = None,
                 enhanced_authentication_enabled: Optional[bool] = None,
                 id: Optional[str] = None,
                 key: Optional[str] = None,
                 key2: Optional[str] = None,
                 storage_enabled: Optional[bool] = None,
                 trusted_origins: Optional[Sequence[str]] = None,
                 user_upload_enabled: Optional[bool] = None,
                 v1_allowed: Optional[bool] = None,
                 v3_allowed: Optional[bool] = None):
        """
        :param str name: The name of the site
        :param bool enabled: Enables/Disables this site. Defaults to `true`.
        :param bool endpoint_parameters_enabled: Is the endpoint parameters enabled for this site?
        :param bool enhanced_authentication_enabled: Enables additional security measures for this site, see [Enhanced Directline Authentication Features](https://blog.botframework.com/2018/09/25/enhanced-direct-line-authentication-features). Disabled by default.
        :param str id: Id for the site
        :param str key: Primary key for accessing this site
        :param str key2: Secondary key for accessing this site
        :param bool storage_enabled: Is the storage site enabled for detailed logging? Defaults to `true`.
        :param Sequence[str] trusted_origins: This field is required when `is_secure_site_enabled` is enabled. Determines which origins can establish a Directline conversation for this site.
        :param bool user_upload_enabled: Is the user upload enabled for this site? Defaults to `true`.
        :param bool v1_allowed: Enables v1 of the Directline protocol for this site. Defaults to `true`.
        :param bool v3_allowed: Enables v3 of the Directline protocol for this site. Defaults to `true`.
        """
        pulumi.set(__self__, "name", name)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if endpoint_parameters_enabled is not None:
            pulumi.set(__self__, "endpoint_parameters_enabled", endpoint_parameters_enabled)
        if enhanced_authentication_enabled is not None:
            pulumi.set(__self__, "enhanced_authentication_enabled", enhanced_authentication_enabled)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if key2 is not None:
            pulumi.set(__self__, "key2", key2)
        if storage_enabled is not None:
            pulumi.set(__self__, "storage_enabled", storage_enabled)
        if trusted_origins is not None:
            pulumi.set(__self__, "trusted_origins", trusted_origins)
        if user_upload_enabled is not None:
            pulumi.set(__self__, "user_upload_enabled", user_upload_enabled)
        if v1_allowed is not None:
            pulumi.set(__self__, "v1_allowed", v1_allowed)
        if v3_allowed is not None:
            pulumi.set(__self__, "v3_allowed", v3_allowed)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the site
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def enabled(self) -> Optional[bool]:
        """
        Enables/Disables this site. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="endpointParametersEnabled")
    def endpoint_parameters_enabled(self) -> Optional[bool]:
        """
        Is the endpoint parameters enabled for this site?
        """
        return pulumi.get(self, "endpoint_parameters_enabled")

    @property
    @pulumi.getter(name="enhancedAuthenticationEnabled")
    def enhanced_authentication_enabled(self) -> Optional[bool]:
        """
        Enables additional security measures for this site, see [Enhanced Directline Authentication Features](https://blog.botframework.com/2018/09/25/enhanced-direct-line-authentication-features). Disabled by default.
        """
        return pulumi.get(self, "enhanced_authentication_enabled")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        Id for the site
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        Primary key for accessing this site
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def key2(self) -> Optional[str]:
        """
        Secondary key for accessing this site
        """
        return pulumi.get(self, "key2")

    @property
    @pulumi.getter(name="storageEnabled")
    def storage_enabled(self) -> Optional[bool]:
        """
        Is the storage site enabled for detailed logging? Defaults to `true`.
        """
        return pulumi.get(self, "storage_enabled")

    @property
    @pulumi.getter(name="trustedOrigins")
    def trusted_origins(self) -> Optional[Sequence[str]]:
        """
        This field is required when `is_secure_site_enabled` is enabled. Determines which origins can establish a Directline conversation for this site.
        """
        return pulumi.get(self, "trusted_origins")

    @property
    @pulumi.getter(name="userUploadEnabled")
    def user_upload_enabled(self) -> Optional[bool]:
        """
        Is the user upload enabled for this site? Defaults to `true`.
        """
        return pulumi.get(self, "user_upload_enabled")

    @property
    @pulumi.getter(name="v1Allowed")
    def v1_allowed(self) -> Optional[bool]:
        """
        Enables v1 of the Directline protocol for this site. Defaults to `true`.
        """
        return pulumi.get(self, "v1_allowed")

    @property
    @pulumi.getter(name="v3Allowed")
    def v3_allowed(self) -> Optional[bool]:
        """
        Enables v3 of the Directline protocol for this site. Defaults to `true`.
        """
        return pulumi.get(self, "v3_allowed")


@pulumi.output_type
class ChannelFacebookPage(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessToken":
            suggest = "access_token"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ChannelFacebookPage. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ChannelFacebookPage.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ChannelFacebookPage.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_token: str,
                 id: str):
        """
        :param str access_token: The Facebook Page Access Token for the Facebook Channel.
        :param str id: The Facebook Page ID for the Facebook Channel.
        """
        pulumi.set(__self__, "access_token", access_token)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> str:
        """
        The Facebook Page Access Token for the Facebook Channel.
        """
        return pulumi.get(self, "access_token")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The Facebook Page ID for the Facebook Channel.
        """
        return pulumi.get(self, "id")


@pulumi.output_type
class ChannelLineLineChannel(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessToken":
            suggest = "access_token"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ChannelLineLineChannel. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ChannelLineLineChannel.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ChannelLineLineChannel.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_token: str,
                 secret: str):
        """
        :param str access_token: The access token which is used to call the Line Channel API.
        :param str secret: The secret which is used to access the Line Channel.
        """
        pulumi.set(__self__, "access_token", access_token)
        pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> str:
        """
        The access token which is used to call the Line Channel API.
        """
        return pulumi.get(self, "access_token")

    @property
    @pulumi.getter
    def secret(self) -> str:
        """
        The secret which is used to access the Line Channel.
        """
        return pulumi.get(self, "secret")


@pulumi.output_type
class ChannelWebChatSite(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "endpointParametersEnabled":
            suggest = "endpoint_parameters_enabled"
        elif key == "storageEnabled":
            suggest = "storage_enabled"
        elif key == "userUploadEnabled":
            suggest = "user_upload_enabled"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ChannelWebChatSite. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ChannelWebChatSite.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ChannelWebChatSite.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: str,
                 endpoint_parameters_enabled: Optional[bool] = None,
                 storage_enabled: Optional[bool] = None,
                 user_upload_enabled: Optional[bool] = None):
        """
        :param str name: The name of the site.
        :param bool endpoint_parameters_enabled: Is the endpoint parameters enabled for this site?
        :param bool storage_enabled: Is the storage site enabled for detailed logging? Defaults to `true`.
        :param bool user_upload_enabled: Is the user upload enabled for this site? Defaults to `true`.
        """
        pulumi.set(__self__, "name", name)
        if endpoint_parameters_enabled is not None:
            pulumi.set(__self__, "endpoint_parameters_enabled", endpoint_parameters_enabled)
        if storage_enabled is not None:
            pulumi.set(__self__, "storage_enabled", storage_enabled)
        if user_upload_enabled is not None:
            pulumi.set(__self__, "user_upload_enabled", user_upload_enabled)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the site.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="endpointParametersEnabled")
    def endpoint_parameters_enabled(self) -> Optional[bool]:
        """
        Is the endpoint parameters enabled for this site?
        """
        return pulumi.get(self, "endpoint_parameters_enabled")

    @property
    @pulumi.getter(name="storageEnabled")
    def storage_enabled(self) -> Optional[bool]:
        """
        Is the storage site enabled for detailed logging? Defaults to `true`.
        """
        return pulumi.get(self, "storage_enabled")

    @property
    @pulumi.getter(name="userUploadEnabled")
    def user_upload_enabled(self) -> Optional[bool]:
        """
        Is the user upload enabled for this site? Defaults to `true`.
        """
        return pulumi.get(self, "user_upload_enabled")


